@@ -450,9 +450,9 @@ void UDrawObject(objinstptr theinstance, short level, int passcolor,
   	  case(LABEL): 
 	     if (level == 0 || TOLABEL(areagen)->pin == False)
                 UDrawString(TOLABEL(areagen), curcolor, theinstance);
-	     else if ((TOLABEL(areagen)->justify & PINVISIBLE) && areawin->pinpointon)
+	     else if ((TOLABEL(areagen)->anchor & PINVISIBLE) && areawin->pinpointon)
                 UDrawString(TOLABEL(areagen), curcolor, theinstance);
-	     else if (TOLABEL(areagen)->justify & PINVISIBLE)
+	     else if (TOLABEL(areagen)->anchor & PINVISIBLE)
                 UDrawStringNoX(TOLABEL(areagen), curcolor, theinstance);
 	     else if (level == 1 && TOLABEL(areagen)->pin &&
 			TOLABEL(areagen)->pin != INFO && areawin->pinpointon)
@@ -663,6 +663,8 @@ void UDrawSpline(splineptr thespline, float passwidth)
 
 void UDrawGraphic(graphicptr gp)
 {
+   double w, h;
+
    if (!areawin->redraw_ongoing) {
       areawin->redraw_needed = True;
       return;
@@ -672,11 +674,14 @@ void UDrawGraphic(graphicptr gp)
    cairo_translate(areawin->cr,
 	 gp->position.x, 
 	 gp->position.y);
-   cairo_rotate(areawin->cr, gp->rotation * M_PI / -180.);
+   cairo_rotate(areawin->cr, -gp->rotation * RADFAC);
    cairo_scale(areawin->cr, gp->scale, -gp->scale);
+   w = cairo_image_surface_get_width(gp->source);
+   h = cairo_image_surface_get_height(gp->source);
    cairo_set_source_surface(areawin->cr, gp->source,
-	 - cairo_image_surface_get_width(gp->source) / 2., 
-	 - cairo_image_surface_get_height(gp->source) / 2.);
+	 -w / 2., -h / 2.);
+   cairo_rectangle(areawin->cr, -w / 2, -h / 2, w, h);
+   cairo_clip(areawin->cr);
    cairo_paint(areawin->cr);
    cairo_restore(areawin->cr);
 }
@@ -1123,7 +1128,8 @@ void xc_cairo_set_fontinfo(size_t fontidx)
 	 fi->glyph_index[c] = glyphs[0].index;
 	 cairo_scaled_font_glyph_extents(scaled_font, glyphs, 1, &extents);
 	 fi->glyph_top[c] = -extents.y_bearing * 40. / 100.;
-	 fi->glyph_bottom[c] = extents.height * 40. / 100. + fi->glyph_top[c];
+	 /* fi->glyph_bottom[c] = extents.height * 40. / 100. + fi->glyph_top[c]; */
+	 fi->glyph_bottom[c] = fi->glyph_top[c] - extents.height * 40. / 100.;
 	 fi->glyph_advance[c] = extents.x_advance * 40. / 100.;
       }
       cairo_glyph_free(glyphs);
