@@ -60,7 +60,7 @@ extern Tcl_Interp *xcinterp;
 
 FILE *findfontfile(char *fontname)
 {
-   int i;
+   size_t i;
    char tempname[256];
    FILE *fd;
 
@@ -296,7 +296,7 @@ int loadfontfile(char *fname)
 	    fonts[fontcount].scale = fontscale;
 #ifdef HAVE_CAIRO
 	    fonts[fontcount].utf8encoding = utf8enc;
-	    xc_cairo_set_fontinfo(fonts + fontcount);
+	    xc_cairo_set_fontinfo(fontcount);
 #endif /* HAVE_CAIRO */
             fontcount++;
 	 }
@@ -403,7 +403,7 @@ int loadfontfile(char *fname)
          fonts[fontcount].scale = fontscale;
 #ifdef HAVE_CAIRO
 	 fonts[fontcount].utf8encoding = utf8enc;
-	 xc_cairo_set_fontinfo(fonts + fontcount);
+	 xc_cairo_set_fontinfo(fontcount);
 #endif /* HAVE_CAIRO */
          fontcount++;
 
