@@ -762,7 +762,7 @@ extern void insertparam(void);
 extern void makeparam(labelptr, char *);
 extern void searchinst(objectptr, objectptr, char *);
 extern stringpart *searchparam(stringpart *);
-extern void unmakeparam(labelptr, stringpart *);
+extern void unmakeparam(labelptr, objinstptr, stringpart *);
 extern void removenumericalp(genericptr *, u_int);         
 extern void unparameterize(int);
 extern void parameterize(int, char *, short);
@@ -802,9 +802,9 @@ extern xcWidget *pytoolbuttons(int *);
 /* from rcfile.c: */
 
 extern short execcommand(short, char *);
-extern void defaultscript(void);
+extern int defaultscript(void);
 extern void execscript(void);
-extern void loadrcfile(void);
+extern int loadrcfile(void);
 #ifndef HAVE_PYTHON
 extern short readcommand(short, FILE *);
 #endif
@@ -1015,7 +1015,7 @@ extern void dointr(int);
 extern void DoNothing(xcWidget, caddr_t, caddr_t);
 extern u_short countchanges(char **);
 extern u_short getchanges(objectptr);
-extern void quitcheck(xcWidget, caddr_t, caddr_t);
+extern int quitcheck(xcWidget, caddr_t, caddr_t);
 extern void quit(xcWidget, caddr_t);
 extern void resizetoolbar(void);
 extern void writescalevalues(char *, char *, char *);
