@@ -12,7 +12,7 @@ typedef unsigned char		u_char;
 typedef unsigned short		u_short;
 typedef unsigned int		u_int;
 typedef unsigned long		u_long;
-typedef unsigned long long	u_long;
+typedef unsigned long long	u_long_long;
 #endif
 
 #ifdef XC_WIN32
@@ -277,9 +277,17 @@ typedef struct {
 } XlPoint;
 
 typedef struct {
-   short width, maxwidth, ascent, descent, base;
+   short width, ascent, descent, base;
+   int maxwidth;
 } TextExtents;
 
+typedef struct {
+   float  *padding;	/* Allocated array of padding info per line	*/
+   XPoint *tbreak;	/* Position in text to stop			*/
+   short  dostop;	/* Location (index) in text to stop 		*/
+   short  line;		/* Stop line number, if using dostop or tbreak. */
+} TextLinesInfo;
+
 /*----------------------------------------------------------------------*/
 /* Implementation-specific definitions 					*/
 /*----------------------------------------------------------------------*/
@@ -376,21 +384,25 @@ enum loadmodes {IMPORT = 1, PSBKGROUND, SCRIPT, RECOVER,
 };
 
 /*----------------------------------------------------------------------*/
-/* Text justification styles and other parameters (bitmask)		*/
+/* Text anchoring styles and other parameters (bitmask)			*/
 /*----------------------------------------------------------------------*/
 
-#define NOTLEFT		1
-#define RIGHT		2
-#define NOTBOTTOM	4
-#define TOP		8
+#define NOTLEFT		1	/* Center or right anchoring		*/
+#define RIGHT		2	/* Right anchoring			*/
+#define NOTBOTTOM	4	/* Middle or top anchoring		*/
+#define TOP		8	/* Top anchoring			*/
 #define FLIPINV		16	/* 1 if text is flip-invariant		*/
 #define PINVISIBLE	32	/* 1 if pin visible outside of object	*/
 #define PINNOOFFSET	64	/* 0 if pin label offset from position	*/
-#define LATEXLABEL	128
+#define LATEXLABEL	128	/* 1 if label is in LaTeX syntax	*/
+#define JUSTIFYRIGHT	256	/* Right text justification		*/
+#define JUSTIFYBOTH	512	/* Right and left text justification	*/
+#define TEXTCENTERED	1024	/* Centered text			*/
 
-#define RLJUSTFIELD	3	/* right-left justification bit field	*/
-#define TBJUSTFIELD	12	/* top-bottom justification bit field	*/
-#define NONJUSTFIELD	240	/* everything but justification fields	*/
+#define RLANCHORFIELD	3	/* right-left anchoring bit field	*/
+#define TBANCHORFIELD	12	/* top-bottom anchoring bit field	*/
+#define NONANCHORFIELD	2032	/* everything but anchoring fields	*/
+#define NONJUSTIFFIELD  255	/* everything but justification fields	*/
 
 /*----------------------------------------------------------------------*/
 /* Text string part: types						*/
@@ -608,7 +620,7 @@ enum paramwhich {
    P_POSITION_X,
    P_POSITION_Y,
    P_STYLE,
-   P_JUSTIFY,
+   P_ANCHOR,
    P_ANGLE1,
    P_ANGLE2,
    P_RADIUS,
@@ -737,7 +749,7 @@ typedef struct {
    eparamptr	passed;		/* numerical parameters passed from above */
    u_short	style;
    XPoint	position;
-   short	rotation;
+   float	rotation;
    float	scale;
    objectptr	thisobject;
    oparamptr	params;		/* parameter substitutions for this instance */
@@ -786,12 +798,12 @@ typedef struct {
    int		  color;	/* foreground, for bitmaps only */
    eparamptr	  passed;	/* numerical parameters passed from above */
    XPoint	  position;
-   short	  rotation;
+   float	  rotation;
    float	  scale;
    xcImage	  *source;	/* source data */
 #ifndef HAVE_CAIRO
    xcImage	  *target;	/* target (scaled) data */
-   short	  trot;		/* target rotation */
+   float	  trot;		/* target rotation */
    float	  tscale;	/* target scale (0 = uninitialized) */
    Pixmap	  clipmask;	/* clipmask for non-manhattan rotations */
    Boolean	  valid;	/* does target need to be regenerated? */
@@ -808,9 +820,9 @@ typedef struct {
    eparamptr	passed;		/* numerical parameters passed from above */
    pointselect	*cycle;		/* Edit position(s), or NULL */
    XPoint	position;
-   short	rotation;
+   float	rotation;
    float	scale;
-   short	justify;
+   u_short	anchor;
    u_char	pin;
    stringpart	*string;
 } label, *labelptr;
@@ -1291,7 +1303,7 @@ typedef struct _keybinding {
 
 enum {
    XCF_ENDDATA = -2,		XCF_SPACER  /* -1 */,
-   XCF_Page	 /* 0 */,	XCF_Justify /* 1 */,
+   XCF_Page	 /* 0 */,	XCF_Anchor /* 1 */,
    XCF_Superscript /* 2 */,	XCF_Subscript /* 3 */,
    XCF_Normalscript /* 4 */,	XCF_Font /* 5 */,
    XCF_Boldfont /* 6 */,	XCF_Italicfont /* 7 */,
@@ -1403,7 +1415,7 @@ typedef struct _windowdata {
 #ifndef HAVE_CAIRO
    Pixmap	clipmask;
    Pixmap	pbuf;		/* clipmask buffer for hierarchical clipping */
-   char		clipped;
+   signed char	clipped;
    GC		cmgc;
 #endif /* !HAVE_CAIRO */
    int		gccolor;
@@ -1430,7 +1442,7 @@ typedef struct _windowdata {
    float	linewidth;
    float	zoomfactor;
    short	psfont;
-   short	justify;
+   u_short	anchor;
    u_short	style;
    int		color;
    short	filter;		/* selection filter */
@@ -1535,7 +1547,7 @@ typedef struct {
    Boolean	hold;		/* allow HOLD modifiers on buttons */
    Boolean	showtech;	/* Write technology names in library */
    u_short	new_changes;
-   char		suspend;	/* suspend graphics updates if TRUE */
+   signed char	suspend;	/* suspend graphics updates if TRUE */
    short	numlibs;
    short	pages;
    Pagedata	**pagelist;
